Module types

Module types 

Enums

ProcessHandling
Controls whether a value should be processed, skipped, or processing cancelled.
TypedValue
Typed value used during encryption/decryption to preserve the original type.
ValueType

Functions

new_key_path
Build a dot-notation key path from a parent path and a key name. e.g. (“second.a”, “v”) -> “second.a.v”, (“”, “first”) -> “first”