pub fn input_type(value: &str) -> (TypedValue, ValueType)Expand description
Parse a string and detect its most specific type. Tries INTEGER, then BOOL, then NUMBER, then falls back to STRING.
pub fn input_type(value: &str) -> (TypedValue, ValueType)Parse a string and detect its most specific type. Tries INTEGER, then BOOL, then NUMBER, then falls back to STRING.