Enums
- Process
Handling - Controls whether a value should be processed, skipped, or processing cancelled.
- Typed
Value - Typed value used during encryption/decryption to preserve the original type.
- Value
Type
Functions
- new_
key_ path - Build a dot-notation key path from a parent path and a key name. e.g. (“second.a”, “v”) -> “second.a.v”, (“”, “first”) -> “first”